import re as _re


def exact_jp(string):
    _jponly = _re.compile('[亜-熙ぁ-んァ-ヶ]')
    return ''.join(_jponly.findall(string))


def exact_letters(string):
    _letters_only = _re.compile('[亜-熙ぁ-んァ-ヶa-zA-Z0-9]')
    return ''.join(_letters_only.findall(string))


def numberize(string):
    return _re.sub(r'\D', '', string)


def numberize_int(string):
    return int(numberize(string))



import boto3 as _boto3
import base64 as _base64


def gen_s3(key, secret_key, region_name):
    """
    gen s3 by keys instead of "boto3.resource('s3')"
    when you didn't do "aws configure" well
    """
    s3 = _boto3.session.Session(
        key=key, secret_key=secret_key, region_name=region_name).resource('s3')
    return s3


def download_text(bucketname, path, s3=None):
    s3 = s3 or _boto3.resource('s3')
    obj = s3.Object(bucketname, path)
    text = _base64.b64decode(obj.get()['Body'].read()).decode()
    return text


def upload_text(bucketname, path, text, public_read=False, ContentType='text/plain;charset=utf-8', s3=None):
    s3 = s3 or _boto3.resource('s3')
    acl = {True: "public-read",
           False: "private"}[public_read]
    print(3)
    response = s3.Bucket(bucketname).put_object(
        ACL=acl, Body=_base64.b64encode(text.encode()), Key=path, ContentType=ContentType)


if __name__ == '__main__':
    text = 'あいう生憎'
    bucketname = 'superfast.umihi.co'
    path = 'encoding.txt'
    upload_text(bucketname, path, text, public_read=True)
    print(download_text(bucketname, path))





import boto3 as _boto3


def put_item(tablename, dict_, region_name='us-west-2'):
    dynamodb = _boto3.resource('dynamodb', region_name=region_name)
    table = dynamodb.Table(tablename)
    return table.put_item(Item=dict_)


def get_item(tablename, dict_, region_name='us-west-2'):
    dynamodb = _boto3.resource('dynamodb', region_name=region_name)
    table = dynamodb.Table(tablename)
    response = table.get_item(Key=dict_)
    return response['Item']


def list_all_tabel_names():
    dynamodb = _boto3.resource('dynamodb')
    table_list = dynamodb.tables.all()
    for table in table_list:
        print(table.table_name)


if __name__ == '__main__':
    list_all_tabel_names()
    dict_ = {'request_id': 0, 'chunk_id': 0, 'value': ['bbb', 'rcoy']}
    print(put_item('requests_superfast_dynamo', dict_))
    dict_ = {'request_id': 8666958513584, 'chunk_id': 0}
    item = get_item('requests_superfast_dynamo', dict_)
    dict_ = {'request_id': 8666958513584, 'chunk_id': 0}
    item = get_item('requests_superfast_dynamo', dict_)
    dict_ = {'request_id': 8666958513584, 'chunk_id': 0}
    item = get_item('requests_superfast_dynamo', dict_)
    dict_ = {'request_id': 8666958513584, 'chunk_id': 0}
    item = get_item('requests_superfast_dynamo', dict_)
    import umihico
    import ast
    compressed_text = item['compressed_text']
    print(ast.literal_eval(umihico.zip.decompress_text(compressed_text)))
